@@ -104,7 +104,7 @@ struct _GrlMediaSource {
  * @remaining: the number of remaining #GrlMedia to process, or
  * GRL_SOURCE_REMAINING_UNKNOWN if it is unknown
  * @user_data: user data passed to the used method
- * @error: (not-error) (type uint): possible #GError generated at processing
+ * @error: (type uint): possible #GError generated at processing
  *
  * Prototype for the callback passed to the media sources' methods
  */
@@ -118,13 +118,15 @@ typedef void (*GrlMediaSourceResultCb) (GrlMediaSource *source,
 /**
  * GrlMediaSourceMetadataCb:
  * @source: a media source
+ * @operation_id: operation identifier
  * @media: (transfer full): a data transfer object
  * @user_data: user data passed to grl_media_source_metadata()
- * @error: (not-error) (type uint): possible #GError generated at processing
+ * @error: (type uint): possible #GError generated at processing
  *
  * Prototype for the callback passed to grl_media_source_metadata()
  */
 typedef void (*GrlMediaSourceMetadataCb) (GrlMediaSource *source,
+                                          guint operation_id,
                                           GrlMedia *media,
                                           gpointer user_data,
                                           const GError *error);
@@ -135,7 +137,7 @@ typedef void (*GrlMediaSourceMetadataCb) (GrlMediaSource *source,
  * @parent: The #GrlMediaBox who parents the @media
  * @media: (transfer full): a data transfer object
  * @user_data: user data passed to grl_media_source_store()
- * @error: (not-error) (type uint): possible #GError generated at processing
+ * @error: (type uint): possible #GError generated at processing
  *
  * Prototype for the callback passed to grl_media_source_store()
  */
@@ -150,7 +152,7 @@ typedef void (*GrlMediaSourceStoreCb) (GrlMediaSource *source,
  * @source: a media source
  * @media: (transfer full): a data transfer object
  * @user_data: user data passed to grl_media_source_remove()
- * @error: (not-error) (type uint): possible #GError generated at processing
+ * @error: (type uint): possible #GError generated at processing
  *
  * Prototype for the callback passed to grl_media_source_remove()
  */
@@ -324,6 +326,7 @@ typedef struct {
 /**
  * GrlMediaSourceMediaFromUriSpec:
  * @source: a media source
+ * @media_from_uri_id: operation identifier
  * @uri: A URI that can be used to identify a media resource
  * @keys: Metadata keys to resolve
  * @flags: Operation flags
@@ -335,6 +338,7 @@ typedef struct {
  */
 typedef struct {
   GrlMediaSource *source;
+  guint media_from_uri_id;
   gchar *uri;
   GList *keys;
   GrlMetadataResolutionFlags flags;
@@ -342,7 +346,7 @@ typedef struct {
   gpointer user_data;
 
   /*< private >*/
-  gpointer _grl_reserved[GRL_PADDING];
+  gpointer _grl_reserved[GRL_PADDING - 1];
 } GrlMediaSourceMediaFromUriSpec;
 
 
@@ -353,7 +357,6 @@ typedef struct _GrlMediaSourceClass GrlMediaSourceClass;
 /**
  * GrlMediaSourceClass:
  * @parent_class: the parent class structure
- * @operation_id: operation identifier
  * @browse: browse through a list of media
  * @search: search for media
  * @query: query for a specific media
@@ -375,8 +378,6 @@ struct _GrlMediaSourceClass {
 
   GrlMetadataSourceClass parent_class;
 
-  guint operation_id;
-
   void (*browse) (GrlMediaSource *source, GrlMediaSourceBrowseSpec *bs);
 
   void (*search) (GrlMediaSource *source, GrlMediaSourceSearchSpec *ss);
@@ -404,7 +405,7 @@ struct _GrlMediaSourceClass {
                                   GError **error);
 
   /*< private >*/
-  gpointer _grl_reserved[GRL_PADDING - 2];
+  gpointer _grl_reserved[GRL_PADDING - 1];
 };
 
 G_BEGIN_DECLS
@@ -496,14 +497,14 @@ void grl_media_source_remove_sync (GrlMediaSource *source,
                                    GError **error);
 
 
-void grl_media_source_cancel (GrlMediaSource *source, guint operation_id);
+G_GNUC_DEPRECATED void grl_media_source_cancel (GrlMediaSource *source, guint operation_id);
 
-void grl_media_source_set_operation_data (GrlMediaSource *source,
-                                          guint operation_id,
-                                          gpointer data);
+G_GNUC_DEPRECATED void grl_media_source_set_operation_data (GrlMediaSource *source,
+                                                            guint operation_id,
+                                                            gpointer data);
 
-gpointer grl_media_source_get_operation_data (GrlMediaSource *source,
-                                              guint operation_id);
+G_GNUC_DEPRECATED gpointer grl_media_source_get_operation_data (GrlMediaSource *source,
+                                                                guint operation_id);
 
 void grl_media_source_set_auto_split_threshold (GrlMediaSource *source,
                                                 guint threshold);
@@ -513,12 +514,12 @@ guint grl_media_source_get_auto_split_threshold (GrlMediaSource *source);
 gboolean grl_media_source_test_media_from_uri (GrlMediaSource *source,
 					       const gchar *uri);
 
-void grl_media_source_get_media_from_uri (GrlMediaSource *source,
-					  const gchar *uri,
-					  const GList *keys,
-					  GrlMetadataResolutionFlags flags,
-					  GrlMediaSourceMetadataCb callback,
-					  gpointer user_data);
+guint grl_media_source_get_media_from_uri (GrlMediaSource *source,
+                                           const gchar *uri,
+                                           const GList *keys,
+                                           GrlMetadataResolutionFlags flags,
+                                           GrlMediaSourceMetadataCb callback,
+                                           gpointer user_data);
 
 GrlMedia *grl_media_source_get_media_from_uri_sync (GrlMediaSource *source,
                                                     const gchar *uri,
@@ -532,6 +533,11 @@ gboolean grl_media_source_notify_change_start (GrlMediaSource *source,
 gboolean grl_media_source_notify_change_stop (GrlMediaSource *source,
                                               GError **error);
 
+void grl_media_source_notify_change_list (GrlMediaSource *source,
+                                          GPtrArray *changed_medias,
+                                          GrlMediaSourceChangeType change_type,
+                                          gboolean location_unknown);
+
 void grl_media_source_notify_change (GrlMediaSource *source,
                                      GrlMedia *media,
                                      GrlMediaSourceChangeType change_type,
